import { HomePage } from '../pages/home'
import { SignPage } from '../pages/sign'
import { LandingPage } from '../pages/landing/LandingPage'
import { Login } from '../pages/login'
import { ProfilePage } from '../pages/profile'
import { hexToNpub } from '../utils'
import { VerifyPage } from '../pages/verify'

export const appPrivateRoutes = {
  homePage: '/',
  sign: '/sign',
  verify: '/verify'
}

export const appPublicRoutes = {
  profile: '/profile/:npub',
  landingPage: '/',
  login: '/login',
  help: 'https://help.sigit.io'
}

export const getProfileRoute = (hexKey: string) =>
  appPublicRoutes.profile.replace(':npub', hexToNpub(hexKey))

export const publicRoutes = [
  {
    path: appPublicRoutes.landingPage,
    hiddenWhenLoggedIn: true,
    element: <LandingPage />
  },
  {
    path: appPublicRoutes.login,
    hiddenWhenLoggedIn: true,
    element: <Login />
  },
  {
    path: appPublicRoutes.profile,
    element: <ProfilePage />
  }
]

export const privateRoutes = [
  {
    path: appPrivateRoutes.homePage,
    element: <HomePage />
  },
  {
    path: appPrivateRoutes.sign,
    element: <SignPage />
  },
  {
    path: appPrivateRoutes.verify,
    element: <VerifyPage />
  }
]
